@@ -8,7 +8,7 @@ include("extensions.jl")
 include("precompile.jl")
 
 # Interface
-export Parser, enable!, disable!, html, latex, term, markdown, notebook, frontmatter
+export Parser, enable!, disable!, html, latex, term, markdown, notebook, typst, frontmatter
 
 # Core block rules
 export AtxHeadingRule,
