@@ -2,13 +2,13 @@
     p = Parser()
     enable!(p, RawContentRule())
 
-    text = "`html`{=html}`latex`{=latex}"
+    text = "`html`{=html}`latex`{=latex}`typst`{=typst}"
     ast = p(text)
 
     @test html(ast) == "<p>html</p>\n"
     @test latex(ast) == "latex\\par\n"
-    @test term(ast) == " \e[90mhtml\e[39m\e[90mlatex\e[39m\n"
-    @test markdown(ast) == "html`latex`{=latex}\n" # TODO: should we pass through a literal instead for html?
+    @test term(ast) == " \e[90mhtml\e[39m\e[90mlatex\e[39m\e[90mtypst\e[39m\n"
+    @test markdown(ast) == "html`latex`{=latex}`typst`{=typst}\n" # TODO: should we pass through a literal instead for html?
 
     text = """
            ```{=html}
@@ -20,15 +20,18 @@
            ...
            \\end{tikzpicture}
            ```
+           ```{=typst}
+           #let name = "Typst"
+           ```
            """
     ast = p(text)
 
     @test html(ast) == "<div id=\"main\">\n <div class=\"article\">\n"
     @test latex(ast) == "\\begin{tikzpicture}\n...\n\\end{tikzpicture}\n"
     @test term(ast) ==
-          " \e[90m<div id=\"main\">\e[39m\n \e[90m <div class=\"article\">\e[39m\n \n \e[90m\\begin{tikzpicture}\e[39m\n \e[90m...\e[39m\n \e[90m\\end{tikzpicture}\e[39m\n"
+          " \e[90m<div id=\"main\">\e[39m\n \e[90m <div class=\"article\">\e[39m\n \n \e[90m\\begin{tikzpicture}\e[39m\n \e[90m...\e[39m\n \e[90m\\end{tikzpicture}\e[39m\n \n \e[90m#let name = \"Typst\"\e[39m\n"
     @test markdown(ast) ==
-          "<div id=\"main\">\n <div class=\"article\">\n\n```{=latex}\n\\begin{tikzpicture}\n...\n\\end{tikzpicture}\n```\n"
+          "<div id=\"main\">\n <div class=\"article\">\n\n```{=latex}\n\\begin{tikzpicture}\n...\n\\end{tikzpicture}\n```\n\n```{=typst}\n#let name = \"Typst\"\n```\n"
 
     p = Parser()
     enable!(p, RawContentRule(text_inline = CommonMark.Text))
