@@ -15,6 +15,7 @@
     @test latex(ast, env) == "\\href{url.md}{link}\\par\n"
     @test term(ast, env) == " \e[34;4mlink\e[39;24m\n"
     @test markdown(ast, env) == "[link](url.md)\n"
+    @test typst(ast, env) == "#link(\"url.md\")[link]\n"
 
     ast = p("![link](url.img)")
     @test html(ast, env) == "<p><img src=\"url.img\" alt=\"link\" /></p>\n"
@@ -22,4 +23,5 @@
           "\\begin{figure}\n\\centering\n\\includegraphics[max width=\\linewidth]{url.img}\n\\caption{link}\n\\end{figure}\n\\par\n"
     @test term(ast, env) == " \e[32mlink\e[39m\n"
     @test markdown(ast, env) == "![link](url.img)\n"
+    @test typst(ast, env) == "#figure(image(\"url.img\"), caption: [link])\n"
 end
